MultiMolecule - MultiMolecule
Description: Neural Networks for RNA, DNA, and Protein

跳转至

# MultiMolecule

## 介绍

欢迎来到 MultiMolecule (浦原)，这是一个通过机器学习加速科学研究的基础库。MultiMolecule 旨在为希望在工作当中使用 AI 的研究人员提供一套全面而灵活的工具。

我们理解 AI4Science 是一个广泛的领域，来自不同学科的研究人员使用各种实践方法。因此，MultiMolecule 设计时考虑了低耦合性，这意味着虽然它提供了完整的功能套件，但每个模块都可以独立使用。这使您可以仅将所需组件集成到现有工作流程中，而不会增加不必要的复杂性。MultiMolecule 提供的主要功能包括：

- `data`: 高效的数据处理和预处理功能，以简化科学数据集的摄取和转换。
- `module`: 旨在提供灵活性和可重用性的模块化组件，适用于各种机器学习任务。
- `models`: 为科学研究应用优化的最先进模型架构，确保高性能和高准确性。
- `tokenisers`: 先进的分词方法，有效处理复杂的科学文本和数据表示。

## 安装

从 PyPI 安装最新的稳定版本：

Bash
    1
    pip install multimolecule

从源代码安装最新版本：

Bash
    1
    pip install git+https://github.com/DLS5-Omics/MultiMolecule

## 引用

如果您在研究中使用 MultiMolecule，请按照以下方式引用我们：

BibTeX
     1
     2
     3
     4
     5
     6
     7
     8
     9
    10
    @software{chen_2024_12638419,
      author    = {Chen, Zhiyuan and Zhu, Sophia Y.},
      title     = {MultiMolecule},
      doi       = {10.5281/zenodo.12638419},
      publisher = {Zenodo},
      url       = {https://doi.org/10.5281/zenodo.12638419},
      year      = 2024,
      month     = may,
      day       = 4
    }

## 许可证

我们相信开放是研究的基础。

MultiMolecule 在 GNU Affero 通用公共许可证下授权。

请加入我们，共同建立一个开放的研究社区。

`SPDX-License-Identifier: AGPL-3.0-or-later`

2024-05-24 13:20:47

#### Cookie Consent

We use cookies to recognize your repeated visits and preferences, as well as to measure the effectiveness of our documentation and whether users find what they're searching for. With your consent, you're helping us to make our documentation better. Please check out our Privacy Notice for more information.

- Google Analytics
- GitHub

管理设定